Increase XSL performance by 30%

From: Date: Sat, 07 Sep 2002 13:33:35 +0000
Subject: Increase XSL performance by 30%
Groups: php.doc 
Request: Send a blank email to phpdoc+get-969348516@lists.php.net to get a copy of this message
Hi, for you who are using XSL stylesheets. On address below there is optimizied version of chunking stylesheet. On my machine with Saxon in took 30% less time to build chunked version of HTML. Jirka -------- Original Message -------- From: Norman Walsh <ndw@nwalsh.com> Subject: DOCBOOK-APPS: Chunking performance To: docbook-apps@lists.oasis-open.org I've been experimenting with improving the performance of the chunking stylesheets. The primary goal of my experiments was to get rid of the hairy (and probably expensive) recalculation of prev/next for each chunk. If you're curious, please give http://nwalsh.com/chunk.xsl and http://nwalsh.com/chunkfast.xsl a try. Try using chunk.xsl with chunk.fast=0 and chunk.fast=1, the output should be the same, but the "fast" version should be faster. Using fast chunking requires support for the exsl:node-set() function (which Saxon and xsltproc provide). Without it, there won't be any difference. The chunkfast.xsl stylesheet may be marginally faster than even the fast version of chunk.xsl. It avoids calling exsl:node-set() repeatedly, but will crash and burn if that function isn't supported. Be seeing you, norm -- Norman Walsh <ndw@nwalsh.com> | It is as easy for the strong man http://www.oasis-open.org/docbook/ | to be strong, as it is for the Chair, DocBook Technical Committee | weak to be weak.--Emerson

« previous php.doc (#969348516) next »